.. -*- mode: rst -*-

|Travis|_ |PythonVersion|

.. |Travis| image:: https://api.travis-ci.com/ramonVDAKKER/credit-risk-modelling.svg?branch=main
.. _Travis: https://travis-ci.com/ramonVDAKKER/credit-risk-modelling

.. |PythonVersion| image:: https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9-blue
.. _PythonVersion: https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9-blue

The **credit-risk-modelling** package contains several functions that are useful in Credit Risk Modelling.
